| init | R Documentation |
Initiate the package by loading the data into parent frame. This
should be done as soon as the package is loaded or attached. This
creates(rewrites) new variables deptable and packmeta to the
environment where it is run from.
init(repository = "CRAN", ...)
repository |
( |
... |
Parameters to be passed to |
Format of packmeta: A dataframe with one row per package with some
metadata.
Format of deptable: Dataframe with three columns pkg_1 (chr), relation
(factor, levels = Depends, Imports, Suggests, LinkingTo,
Enhances), pkg_2 (chr)
TRUE (invisibly)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.