Learn R Programming

pkggraph (version 0.3.0)

pkggraph-package: pkggraph: Explore the R Package Dependencies on the Comprehensive R Archive Network (CRAN) Like Repositories

Description

Explore various dependencies of a package(s) (on the Comprehensive R Archive Network Like repositories). The functions `get_neighborhood` and `get_dependencies` provide dependencies of packages and `as_graph` can be used to convert into a igraph object for further analysis and plotting.

Arguments

Author

Maintainer: Komala Sheshachala Srikanth sri.teach@gmail.com

Authors:

See Also